==> apiconnect-cli-subscriptions-1.1.1.tgz: package/lib/plugin-def.js <==
#!/usr/bin/env node
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-policies
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/
var g = require('strong-globalize')();

module.exports = {
  name: 'subscriptions',
  version: require('../package.json').version,
  path: __filename,
  isBuiltin: true,
  topics: topics,
};

function topics() {
  return [ {
    name: 'subscriptions',
    helpInfo: g.f('apic_subscriptions_list_help.txt'),
    commands: [
      {
        command: 'list',
        loginRequired: 'org',
        defaultType: true,
        aliases: [ 'subscriptions' ],
        helpInfo: g.f('apic_subscriptions_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').list(opts);
        },
        type: 'catalog',
        options: [
          { name: 'product', rune: 'p' },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'list',
        loginRequired: 'org',
        helpInfo: g.f('apic_subscriptions_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').list(opts);
        },
        type: 'space',
        options: [
          { name: 'space', type: 'name', required: true },
          { name: 'product', rune: 'p' },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.space.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.space.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.space.hostname', required: true },
        ],
      },
      {
        command: 'list',
        loginRequired: 'org',
        helpInfo: g.f('apic_subscriptions_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').list(opts);
        },
        type: 'consumer-org',
        options: [
          { name: 'application', rune: 'a', type: 'name' },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'get <name>',
        loginRequired: 'org',
        defaultType: true,
        helpInfo: g.f('apic_subscriptions_get_help.txt'),
        action: function(name, opts) {
          return require('./plugin-impl').get(name, opts);
        },
        type: 'catalog',
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'get <name>',
        loginRequired: 'org',
        helpInfo: g.f('apic_subscriptions_get_help.txt'),
        action: function(name, opts) {
          return require('./plugin-impl').get(name, opts);
        },
        type: 'space',
        options: [
          { name: 'space', type: 'name', required: true },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.space.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.space.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.space.hostname', required: true },
        ],
      },
    ],
  },
  ];
};

==> apiconnect-cli-subscriptions-1.2.0.tgz: package/lib/plugin-def.js <==
#!/usr/bin/env node
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-policies
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/
var g = require('strong-globalize')();

module.exports = {
  name: 'subscriptions',
  version: require('../package.json').version,
  path: __filename,
  isBuiltin: true,
  topics: topics,
};

function topics() {
  return [ {
    name: 'subscriptions',
    helpInfo: g.f('apic_subscriptions_list_help.txt'),
    commands: [
      {
        command: 'list',
        loginRequired: 'org',
        defaultType: true,
        aliases: [ 'subscriptions' ],
        helpInfo: g.f('apic_subscriptions_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').list(opts);
        },
        type: 'catalog',
        options: [
          { name: 'product', rune: 'p' },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'host', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'list',
        loginRequired: 'org',
        helpInfo: g.f('apic_subscriptions_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').list(opts);
        },
        type: 'space',
        options: [
          { name: 'space', type: 'name', required: true },
          { name: 'product', rune: 'p' },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.space.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.space.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'host', default: '$APIC_CONFIG$.space.host', required: true },
        ],
      },
      {
        command: 'list',
        loginRequired: 'org',
        helpInfo: g.f('apic_subscriptions_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').list(opts);
        },
        type: 'consumer-org',
        options: [
          { name: 'application', rune: 'a', type: 'name' },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'host', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'get <name>',
        loginRequired: 'org',
        defaultType: true,
        helpInfo: g.f('apic_subscriptions_get_help.txt'),
        action: function(name, opts) {
          return require('./plugin-impl').get(name, opts);
        },
        type: 'catalog',
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'host', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'get <name>',
        loginRequired: 'org',
        helpInfo: g.f('apic_subscriptions_get_help.txt'),
        action: function(name, opts) {
          return require('./plugin-impl').get(name, opts);
        },
        type: 'space',
        options: [
          { name: 'space', type: 'name', required: true },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.space.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.space.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'host', default: '$APIC_CONFIG$.space.host', required: true },
        ],
      },
    ],
  },
  ];
};
